summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rwxr-xr-xsrc/AutoComplete.cpp4
-rwxr-xr-xsrc/AutoComplete.h2
-rwxr-xr-xsrc/CallTip.cpp2
-rwxr-xr-xsrc/CallTip.h2
-rwxr-xr-xsrc/Editor.cpp26
-rwxr-xr-xsrc/Editor.h6
-rw-r--r--src/ExternalLexer.h2
-rwxr-xr-xsrc/Indicator.cpp2
-rw-r--r--src/LexBasic.cpp2
-rwxr-xr-xsrc/LexCLW.cpp6
-rwxr-xr-xsrc/LexCPP.cpp6
-rw-r--r--src/LexCaml.cpp2
-rwxr-xr-xsrc/LexErlang.cpp48
-rwxr-xr-xsrc/LexMatlab.cpp4
-rw-r--r--src/LexRebol.cpp4
-rwxr-xr-xsrc/LexSQL.cpp4
-rw-r--r--src/LexSmalltalk.cpp4
-rw-r--r--src/LexTADS3.cpp16
-rw-r--r--src/LexTCL.cpp36
-rwxr-xr-xsrc/LineMarker.cpp2
-rwxr-xr-xsrc/ViewStyle.cpp2
-rw-r--r--src/XPM.cpp4
-rw-r--r--src/XPM.h6
23 files changed, 96 insertions, 96 deletions
diff --git a/src/AutoComplete.cpp b/src/AutoComplete.cpp
index 753adca..daa5fbb 100755
--- a/src/AutoComplete.cpp
+++ b/src/AutoComplete.cpp
@@ -45,11 +45,11 @@ bool AutoComplete::Active() {
void AutoComplete::Start(Window &parent, int ctrlID,
int position, Point location, int startLen_,
- int lineHeight, bool unicodeMode) {
+ int lineHeight, bool tqunicodeMode) {
if (active) {
Cancel();
}
- lb->Create(parent, ctrlID, location, lineHeight, unicodeMode);
+ lb->Create(parent, ctrlID, location, lineHeight, tqunicodeMode);
lb->Clear();
active = true;
startLen = startLen_;
diff --git a/src/AutoComplete.h b/src/AutoComplete.h
index 10577ca..8fd84c8 100755
--- a/src/AutoComplete.h
+++ b/src/AutoComplete.h
@@ -36,7 +36,7 @@ public:
/// Display the auto completion list positioned to be near a character position
void Start(Window &parent, int ctrlID, int position, Point location,
- int startLen_, int lineHeight, bool unicodeMode);
+ int startLen_, int lineHeight, bool tqunicodeMode);
/// The stop chars are characters which, when typed, cause the auto completion list to disappear
void SetStopChars(const char *stopChars_);
diff --git a/src/CallTip.cpp b/src/CallTip.cpp
index f4bc5f8..2de8eae 100755
--- a/src/CallTip.cpp
+++ b/src/CallTip.cpp
@@ -214,7 +214,7 @@ void CallTip::PaintCT(Surface *surfaceWindow) {
surfaceWindow->FillRectangle(rcClient, colourBG.allocated);
- offsetMain = insetX; // initial alignment assuming no arrows
+ offsetMain = insetX; // initial tqalignment assuming no arrows
PaintContents(surfaceWindow, true);
// Draw a raised border around the edges of the window
diff --git a/src/CallTip.h b/src/CallTip.h
index 9848a10..1fd38c3 100755
--- a/src/CallTip.h
+++ b/src/CallTip.h
@@ -18,7 +18,7 @@ class CallTip {
PRectangle rectUp; // rectangle of last up angle in the tip
PRectangle rectDown; // rectangle of last down arrow in the tip
int lineHeight; // vertical line spacing
- int offsetMain; // The alignment point of the call tip
+ int offsetMain; // The tqalignment point of the call tip
int tabSize; // Tab size in pixels, <=0 no TAB expand
bool useStyleCallTip; // if true, STYLE_CALLTIP should be used
diff --git a/src/Editor.cpp b/src/Editor.cpp
index 67440f1..1abb78a 100755
--- a/src/Editor.cpp
+++ b/src/Editor.cpp
@@ -346,7 +346,7 @@ Editor::Editor() {
hasFocus = false;
hideSelection = false;
inOverstrike = false;
- errorStatus = 0;
+ errortqStatus = 0;
mouseDownCaptures = true;
bufferedDraw = true;
@@ -1246,7 +1246,7 @@ void Editor::EnsureCaretVisible(bool useMargin, bool vert, bool horiz) {
int lineCaret = DisplayFromPosition(posCaret);
bool bSlop, bStrict, bJump, bEven;
- // Vertical positioning
+ //Qt::Vertical positioning
if (vert && (pt.y < rcClient.top || ptBottomCaret.y > rcClient.bottom || (caretYPolicy & CARET_STRICT) != 0)) {
int linesOnScreen = LinesOnScreen();
int halfScreen = Platform::Maximum(linesOnScreen - 1, 2) / 2;
@@ -1340,7 +1340,7 @@ void Editor::EnsureCaretVisible(bool useMargin, bool vert, bool horiz) {
}
}
- // Horizontal positioning
+ //Qt::Horizontal positioning
if (horiz && (wrapState == eWrapNone)) {
int halfScreen = Platform::Maximum(rcClient.Width() - 4, 4) / 2;
int xOffsetNew = xOffset;
@@ -1949,7 +1949,7 @@ void Editor::LayoutLine(int line, Surface *surface, ViewStyle &vstyle, LineLayou
// See if chars, styles, indicators, are all the same
bool allSame = true;
const int styleMask = pdoc->stylingBitsMask;
- // Check base line layout
+ // Check base line tqlayout
char styleByte = 0;
int numCharsInLine = 0;
while (numCharsInLine < lineLength) {
@@ -1997,7 +1997,7 @@ void Editor::LayoutLine(int line, Surface *surface, ViewStyle &vstyle, LineLayou
char styleByte = 0;
int styleMask = pdoc->stylingBitsMask;
ll->styleBitsSet = 0;
- // Fill base line layout
+ // Fill base line tqlayout
for (int charInDoc = posLineStart; charInDoc < posLineEnd; charInDoc++) {
char chDoc = pdoc->CharAt(charInDoc);
styleByte = pdoc->StyleAt(charInDoc);
@@ -2815,7 +2815,7 @@ void Editor::Paint(Surface *surfaceWindow, PRectangle rcArea) {
startLineToWrap = -1;
if (WrapLines(false, startLineToWrap)) {
// The wrapping process has changed the height of some lines so
- // abandon this paint for a complete repaint.
+ // abandon this paint for a complete tqrepaint.
if (AbandonPaint()) {
return;
}
@@ -2892,7 +2892,7 @@ void Editor::Paint(Surface *surfaceWindow, PRectangle rcArea) {
//ElapsedTime et;
if (lineDoc != lineDocPrevious) {
ll.Set(0);
- // For rectangular selection this accesses the layout cache so should be after layout returned.
+ // For rectangular selection this accesses the tqlayout cache so should be after tqlayout returned.
lineIterator.SetAt(lineDoc);
ll.Set(RetrieveLineLayout(lineDoc));
LayoutLine(lineDoc, surface, vs, ll, wrapWidth);
@@ -2930,7 +2930,7 @@ void Editor::Paint(Surface *surfaceWindow, PRectangle rcArea) {
DrawLine(surface, vs, lineDoc, visibleLine, xStart, rcLine, ll, subLine);
//durPaint += et.Duration(true);
- // Restore the previous styles for the brace highlights in case layout is in cache.
+ // Restore the previous styles for the brace highlights in case tqlayout is in cache.
ll->RestoreBracesHighlight(rangeLine, braces);
bool expanded = cs.GetExpanded(lineDoc);
@@ -3372,7 +3372,7 @@ void Editor::AddCharUTF(char *s, unsigned int len, bool treatAsDBCS) {
// characters representing themselves.
} else {
// Unroll 1 to 3 byte UTF-8 sequences. See reference data at:
- // http://www.cl.cam.ac.uk/~mgk25/unicode.html
+ // http://www.cl.cam.ac.uk/~mgk25/tqunicode.html
// http://www.cl.cam.ac.uk/~mgk25/ucs/examples/UTF-8-test.txt
if (byte < 0xE0) {
int byte2 = static_cast<unsigned char>(s[1]);
@@ -3809,7 +3809,7 @@ void Editor::NotifyModified(Document*, DocModification mh, void *) {
}
//Platform::DebugPrintf("** %x Doc Changed\n", this);
- // TODO: could invalidate from mh.startModification to end of screen
+ // TODO: could tqinvalidate from mh.startModification to end of screen
//InvalidateRange(mh.position, mh.position + mh.length);
if (paintState == notPainting && !CanDeferToLastStep(mh)) {
Redraw();
@@ -5217,7 +5217,7 @@ void Editor::SetHotSpotRange(Point *pt) {
int hsStart_ = pdoc->ExtendStyleRange(pos, -1, vs.hotspotSingleLine);
int hsEnd_ = pdoc->ExtendStyleRange(pos, 1, vs.hotspotSingleLine);
- // Only invalidate the range if the hotspot range has changed...
+ // Only tqinvalidate the range if the hotspot range has changed...
if (hsStart_ != hsStart || hsEnd_ != hsEnd) {
if (hsStart != -1) {
InvalidateRange(hsStart, hsEnd);
@@ -7210,11 +7210,11 @@ sptr_t Editor::WndProc(unsigned int iMessage, uptr_t wParam, sptr_t lParam) {
return hasFocus;
case SCI_SETSTATUS:
- errorStatus = wParam;
+ errortqStatus = wParam;
break;
case SCI_GETSTATUS:
- return errorStatus;
+ return errortqStatus;
case SCI_SETMOUSEDOWNCAPTURES:
mouseDownCaptures = wParam != 0;
diff --git a/src/Editor.h b/src/Editor.h
index fe7be26..d5abdbd 100755
--- a/src/Editor.h
+++ b/src/Editor.h
@@ -204,7 +204,7 @@ protected: // ScintillaBase subclass needs access to much of Editor
bool hasFocus;
bool hideSelection;
bool inOverstrike;
- int errorStatus;
+ int errortqStatus;
bool mouseDownCaptures;
/** In bufferedDraw mode, graphics operations are drawn to a pixmap and then copied to
@@ -214,7 +214,7 @@ protected: // ScintillaBase subclass needs access to much of Editor
* and then the foreground. This avoids chopping off characters that overlap the next run. */
bool twoPhaseDraw;
- int xOffset; ///< Horizontal scrolled amount in pixels
+ int xOffset; ///<Qt::Horizontal scrolled amount in pixels
int xCaretMargin; ///< Ensure this many pixels visible on both sides of caret
bool horizontalScrollBarVisible;
int scrollWidth;
@@ -368,7 +368,7 @@ protected: // ScintillaBase subclass needs access to much of Editor
void ScrollTo(int line, bool moveThumb=true);
virtual void ScrollText(int linesToMove);
- void HorizontalScrollTo(int xPos);
+ voidQt::HorizontalScrollTo(int xPos);
void MoveCaretInsideView(bool ensureVisible=true);
int DisplayFromPosition(int pos);
void EnsureCaretVisible(bool useMargin=true, bool vert=true, bool horiz=true);
diff --git a/src/ExternalLexer.h b/src/ExternalLexer.h
index fe9da36..b21dab9 100644
--- a/src/ExternalLexer.h
+++ b/src/ExternalLexer.h
@@ -13,7 +13,7 @@
#elif PLAT_GTK
#define EXT_LEXER_DECL
#elif PLAT_QT
-#include <qglobal.h>
+#include <tqglobal.h>
#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
#define EXT_LEXER_DECL __stdcall
#else
diff --git a/src/Indicator.cpp b/src/Indicator.cpp
index 7624a4a..de321a0 100755
--- a/src/Indicator.cpp
+++ b/src/Indicator.cpp
@@ -13,7 +13,7 @@
void Indicator::Draw(Surface *surface, const PRectangle &rc, const PRectangle &rcLine) {
surface->PenColour(fore.allocated);
int ymid = (rc.bottom + rc.top) / 2;
- if (style == INDIC_SQUIGGLE) {
+ if (style == INDIC_STQUIGGLE) {
surface->MoveTo(rc.left, rc.top);
int x = rc.left + 2;
int y = 2;
diff --git a/src/LexBasic.cpp b/src/LexBasic.cpp
index 79ba2b8..79ca185 100644
--- a/src/LexBasic.cpp
+++ b/src/LexBasic.cpp
@@ -163,7 +163,7 @@ static void ColouriseBasicDoc(unsigned int startPos, int length, int initStyle,
wasfirst = isfirst;
sc.SetState(SCE_B_IDENTIFIER);
} else if (sc.Match(comment_char)) {
- // Hack to make deprecated QBASIC '$Include show
+ // Hack to make deprecated TQBASIC '$Include show
// up in freebasic with SCE_B_PREPROCESSOR.
if (comment_char == '\'' && sc.Match(comment_char, '$'))
sc.SetState(SCE_B_PREPROCESSOR);
diff --git a/src/LexCLW.cpp b/src/LexCLW.cpp
index e28e4b1..5bacdb6 100755
--- a/src/LexCLW.cpp
+++ b/src/LexCLW.cpp
@@ -277,7 +277,7 @@ static void ColouriseClarionDoc(unsigned int uiStartPos, int iLength, int iInitS
// If statement string is in the equate list
if (wlStandardEquates.InList(cEquate)) {
// Change to equate state
- scDoc.ChangeState(SCE_CLW_STANDARD_EQUATE);
+ scDoc.ChangeState(SCE_CLW_STANDARD_ETQUATE);
}
}
// If the character is not a valid label character
@@ -322,7 +322,7 @@ static void ColouriseClarionDoc(unsigned int uiStartPos, int iLength, int iInitS
// Else if statement string is in the standard equate keyword list
else if (wlStandardEquates.InList(cStatement)) {
// Change the statement string to the standard equate state
- scDoc.ChangeState(SCE_CLW_STANDARD_EQUATE);
+ scDoc.ChangeState(SCE_CLW_STANDARD_ETQUATE);
}
// Else if statement string is in the deprecated or legacy keyword list
else if (wlLegacyStatements.InList(cStatement)) {
@@ -380,7 +380,7 @@ static void ColouriseClarionDoc(unsigned int uiStartPos, int iLength, int iInitS
}
}
// Standard Equate State Handling
- else if (scDoc.state == SCE_CLW_STANDARD_EQUATE) {
+ else if (scDoc.state == SCE_CLW_STANDARD_ETQUATE) {
if (!isalnum(scDoc.ch)) {
scDoc.SetState(SCE_CLW_DEFAULT);
}
diff --git a/src/LexCaml.cpp b/src/LexCaml.cpp
index 5f4fad5..4c5ac4a 100644
--- a/src/LexCaml.cpp
+++ b/src/LexCaml.cpp
@@ -355,7 +355,7 @@ void ColouriseCamlDoc(
else
state2 = SCE_CAML_DEFAULT;
chColor++;
- // enable "magic" (read-only) comment AS REQUIRED
+ // enable "magic" (read-only) comment AS RETQUIRED
} else if (useMagic && sc.currentPos - chToken == 4
&& sc.Match('c') && sc.chPrev == 'r' && sc.GetRelative(-2) == '@')
sc.state |= 0x10; // (switch to read-only comment style)
diff --git a/src/LexErlang.cpp b/src/LexErlang.cpp
index 9444eb9..633ea96 100755
--- a/src/LexErlang.cpp
+++ b/src/LexErlang.cpp
@@ -47,17 +47,17 @@ static int is_radix(int radix, int ch) {
typedef enum {
STATE_NULL,
- ATOM_UNQUOTED,
- ATOM_QUOTED,
+ ATOM_UNTQUOTED,
+ ATOM_TQUOTED,
ATOM_FUN_NAME,
- NODE_NAME_UNQUOTED,
- NODE_NAME_QUOTED,
+ NODE_NAME_UNTQUOTED,
+ NODE_NAME_TQUOTED,
MACRO_START,
- MACRO_UNQUOTED,
- MACRO_QUOTED,
+ MACRO_UNTQUOTED,
+ MACRO_TQUOTED,
RECORD_START,
- RECORD_UNQUOTED,
- RECORD_QUOTED,
+ RECORD_UNTQUOTED,
+ RECORD_TQUOTED,
NUMERAL_START,
NUMERAL_SIGNED,
NUMERAL_RADIX_LITERAL,
@@ -85,9 +85,9 @@ static void ColouriseErlangDoc(unsigned int startPos, int length, int initStyle,
case STATE_NULL:
sc.SetState(SCE_ERLANG_DEFAULT);
break;
- case ATOM_UNQUOTED:
+ case ATOM_UNTQUOTED:
if ( '@' == sc.ch ){
- parse_state = NODE_NAME_UNQUOTED;
+ parse_state = NODE_NAME_UNTQUOTED;
} else if ( !isalnum(sc.ch) && sc.ch != '_' ) {
char s[100];
sc.GetCurrent(s, sizeof(s));
@@ -106,9 +106,9 @@ static void ColouriseErlangDoc(unsigned int startPos, int length, int initStyle,
}
}
break;
- case ATOM_QUOTED:
+ case ATOM_TQUOTED:
if ( '@' == sc.ch ){
- parse_state = NODE_NAME_QUOTED;
+ parse_state = NODE_NAME_TQUOTED;
} else if ( '\'' == sc.ch && '\\' != sc.chPrev ) {
sc.ChangeState(SCE_ERLANG_ATOM);
sc.ForwardSetState(SCE_ERLANG_DEFAULT);
@@ -122,7 +122,7 @@ static void ColouriseErlangDoc(unsigned int startPos, int length, int initStyle,
parse_state = STATE_NULL;
}
break;
- case NODE_NAME_QUOTED:
+ case NODE_NAME_TQUOTED:
if ( '@' == sc.ch ) {
sc.SetState(SCE_ERLANG_DEFAULT);
parse_state = STATE_NULL;
@@ -132,7 +132,7 @@ static void ColouriseErlangDoc(unsigned int startPos, int length, int initStyle,
parse_state = STATE_NULL;
}
break;
- case NODE_NAME_UNQUOTED:
+ case NODE_NAME_UNTQUOTED:
if ( '@' == sc.ch ) {
sc.SetState(SCE_ERLANG_DEFAULT);
parse_state = STATE_NULL;
@@ -144,22 +144,22 @@ static void ColouriseErlangDoc(unsigned int startPos, int length, int initStyle,
break;
case RECORD_START:
if ( '\'' == sc.ch ) {
- parse_state = RECORD_QUOTED;
+ parse_state = RECORD_TQUOTED;
} else if (isalpha(sc.ch) && islower(sc.ch)) {
- parse_state = RECORD_UNQUOTED;
+ parse_state = RECORD_UNTQUOTED;
} else { // error
sc.SetState(SCE_ERLANG_DEFAULT);
parse_state = STATE_NULL;
}
break;
- case RECORD_QUOTED:
+ case RECORD_TQUOTED:
if ( '\'' == sc.ch && '\\' != sc.chPrev ) {
sc.ChangeState(SCE_ERLANG_RECORD);
sc.ForwardSetState(SCE_ERLANG_DEFAULT);
parse_state = STATE_NULL;
}
break;
- case RECORD_UNQUOTED:
+ case RECORD_UNTQUOTED:
if ( !isalpha(sc.ch) && '_' != sc.ch ) {
sc.ChangeState(SCE_ERLANG_RECORD);
sc.SetState(SCE_ERLANG_DEFAULT);
@@ -168,22 +168,22 @@ static void ColouriseErlangDoc(unsigned int startPos, int length, int initStyle,
break;
case MACRO_START:
if ( '\'' == sc.ch ) {
- parse_state = MACRO_QUOTED;
+ parse_state = MACRO_TQUOTED;
} else if (isalpha(sc.ch)) {
- parse_state = MACRO_UNQUOTED;
+ parse_state = MACRO_UNTQUOTED;
} else { // error
sc.SetState(SCE_ERLANG_DEFAULT);
parse_state = STATE_NULL;
}
break;
- case MACRO_UNQUOTED:
+ case MACRO_UNTQUOTED:
if ( !isalpha(sc.ch) && '_' != sc.ch ) {
sc.ChangeState(SCE_ERLANG_MACRO);
sc.SetState(SCE_ERLANG_DEFAULT);
parse_state = STATE_NULL;
}
break;
- case MACRO_QUOTED:
+ case MACRO_TQUOTED:
if ( '\'' == sc.ch && '\\' != sc.chPrev ) {
sc.ChangeState(SCE_ERLANG_MACRO);
sc.ForwardSetState(SCE_ERLANG_DEFAULT);
@@ -327,7 +327,7 @@ static void ColouriseErlangDoc(unsigned int startPos, int length, int initStyle,
} else if (sc.ch == '$') {
sc.SetState(SCE_ERLANG_CHARACTER);
} else if (sc.ch == '\'') {
- parse_state = ATOM_QUOTED;
+ parse_state = ATOM_TQUOTED;
sc.SetState(SCE_ERLANG_UNKNOWN);
} else if ( isdigit(sc.ch) ) {
parse_state = NUMERAL_START;
@@ -339,7 +339,7 @@ static void ColouriseErlangDoc(unsigned int startPos, int length, int initStyle,
} else if (isalpha(sc.ch) && isupper(sc.ch)) {
sc.SetState(SCE_ERLANG_VARIABLE);
} else if (isalpha(sc.ch)) {
- parse_state = ATOM_UNQUOTED;
+ parse_state = ATOM_UNTQUOTED;
sc.SetState(SCE_ERLANG_UNKNOWN);
} else if (isoperator(static_cast<char>(sc.ch)) || sc.ch == '\\') {
sc.SetState(SCE_ERLANG_OPERATOR);
diff --git a/src/LexMatlab.cpp b/src/LexMatlab.cpp
index 249fa67..79b4101 100755
--- a/src/LexMatlab.cpp
+++ b/src/LexMatlab.cpp
@@ -103,7 +103,7 @@ static void ColouriseMatlabOctaveDoc(
if (sc.ch == '\'' && sc.chPrev != '\\') {
sc.ForwardSetState(SCE_MATLAB_DEFAULT);
}
- } else if (sc.state == SCE_MATLAB_DOUBLEQUOTESTRING) {
+ } else if (sc.state == SCE_MATLAB_DOUBLETQUOTESTRING) {
if (sc.ch == '"' && sc.chPrev != '\\') {
sc.ForwardSetState(SCE_MATLAB_DEFAULT);
}
@@ -126,7 +126,7 @@ static void ColouriseMatlabOctaveDoc(
sc.SetState(SCE_MATLAB_STRING);
}
} else if (sc.ch == '"') {
- sc.SetState(SCE_MATLAB_DOUBLEQUOTESTRING);
+ sc.SetState(SCE_MATLAB_DOUBLETQUOTESTRING);
} else if (isdigit(sc.ch) || (sc.ch == '.' && isdigit(sc.chNext))) {
sc.SetState(SCE_MATLAB_NUMBER);
} else if (isalpha(sc.ch)) {
diff --git a/src/LexRebol.cpp b/src/LexRebol.cpp
index f829c1e..79d194a 100644
--- a/src/LexRebol.cpp
+++ b/src/LexRebol.cpp
@@ -190,7 +190,7 @@ static void ColouriseRebolDoc(unsigned int startPos, int length, int initStyle,
}
//--- Determine if the current state should terminate
- if (sc.state == SCE_REBOL_QUOTEDSTRING || sc.state == SCE_REBOL_CHARACTER) {
+ if (sc.state == SCE_REBOL_TQUOTEDSTRING || sc.state == SCE_REBOL_CHARACTER) {
if (sc.ch == '^' && sc.chNext == '\"') {
sc.Forward();
} else if (sc.ch == '\"') {
@@ -243,7 +243,7 @@ static void ColouriseRebolDoc(unsigned int startPos, int length, int initStyle,
dotCount = 0;
sc.SetState(SCE_REBOL_NUMBER);
} else if (sc.ch == '\"') {
- sc.SetState(SCE_REBOL_QUOTEDSTRING);
+ sc.SetState(SCE_REBOL_TQUOTEDSTRING);
} else if (sc.ch == '{') {
sc.SetState(blockComment ? SCE_REBOL_COMMENTBLOCK : SCE_REBOL_BRACEDSTRING);
++stringLevel;
diff --git a/src/LexSQL.cpp b/src/LexSQL.cpp
index d8e14b9..f5d3598 100755
--- a/src/LexSQL.cpp
+++ b/src/LexSQL.cpp
@@ -100,7 +100,7 @@ static void ColouriseSQLDoc(unsigned int startPos, int length, int initStyle, Wo
sc.SetState(nextState);
}
break;
- case SCE_SQL_QUOTEDIDENTIFIER:
+ case SCE_SQL_TQUOTEDIDENTIFIER:
if (sc.ch == 0x60) {
if (sc.chNext == 0x60) {
sc.Forward(); // Ignore it
@@ -181,7 +181,7 @@ static void ColouriseSQLDoc(unsigned int startPos, int length, int initStyle, Wo
} else if (IsAWordStart(sc.ch)) {
sc.SetState(SCE_SQL_IDENTIFIER);
} else if (sc.ch == 0x60 && sqlBackticksIdentifier) {
- sc.SetState(SCE_SQL_QUOTEDIDENTIFIER);
+ sc.SetState(SCE_SQL_TQUOTEDIDENTIFIER);
} else if (sc.Match('/', '*')) {
if (sc.Match("/**") || sc.Match("/*!")) { // Support of Doxygen doc. style
sc.SetState(SCE_SQL_COMMENTDOC);
diff --git a/src/LexSmalltalk.cpp b/src/LexSmalltalk.cpp
index 6f43ec3..96b942a 100644
--- a/src/LexSmalltalk.cpp
+++ b/src/LexSmalltalk.cpp
@@ -30,10 +30,10 @@ classificationBlock := [ :charClass :chars |
classificationBlock
value: #DecDigit value: '0123456789';
- value: #Letter value: '_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
+ value: #Letter value: '_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPTQRSTUVWXYZ';
value: #Special value: '()[]{};.^:';
value: #BinSel value: '~@%&*-+=|\/,<>?!';
- value: #Upper value: 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'.
+ value: #Upper value: 'ABCDEFGHIJKLMNOPTQRSTUVWXYZ'.
((String new: 500) streamContents: [ :stream |
stream crLf; nextPutAll: 'static int ClassificationTable[256] = {'.
diff --git a/src/LexTADS3.cpp b/src/LexTADS3.cpp
index 9938f63..03a4074 100644
--- a/src/LexTADS3.cpp
+++ b/src/LexTADS3.cpp
@@ -50,7 +50,7 @@
#include "Scintilla.h"
#include "SciLexer.h"
-static const int T3_SINGLE_QUOTE = 1;
+static const int T3_SINGLE_TQUOTE = 1;
static const int T3_INT_EXPRESSION = 2;
static inline bool IsEOL(const int ch, const int chNext) {
@@ -106,7 +106,7 @@ static void ColouriseTADSHTMLString(StyleContext &sc, int &lineState) {
int endState = sc.state;
int chQuote = sc.ch;
if (endState == SCE_T3_HTML_STRING) {
- if (lineState&T3_SINGLE_QUOTE) {
+ if (lineState&T3_SINGLE_TQUOTE) {
endState = SCE_T3_S_STRING;
chQuote = '"';
} else if (lineState&T3_INT_EXPRESSION) {
@@ -171,7 +171,7 @@ static void ColouriseTADS3HTMLTag(StyleContext &sc, int &lineState) {
sc.SetState(SCE_T3_HTML_DEFAULT);
break;
case SCE_T3_HTML_DEFAULT:
- if (lineState&T3_SINGLE_QUOTE) {
+ if (lineState&T3_SINGLE_TQUOTE) {
endState = SCE_T3_S_STRING;
chQuote = '\'';
chString = '"';
@@ -261,7 +261,7 @@ static void ColouriseTADS3MsgParam(StyleContext &sc, int &lineState) {
sc.Forward();
break;
case SCE_T3_MSG_PARAM:
- if (lineState&T3_SINGLE_QUOTE) {
+ if (lineState&T3_SINGLE_TQUOTE) {
endState = SCE_T3_S_STRING;
chQuote = '\'';
} else if (lineState&T3_INT_EXPRESSION) {
@@ -301,7 +301,7 @@ static void ColouriseTADS3LibDirective(StyleContext &sc, int &lineState) {
sc.Forward(2);
break;
case SCE_T3_LIB_DIRECTIVE:
- if (lineState&T3_SINGLE_QUOTE) {
+ if (lineState&T3_SINGLE_TQUOTE) {
initState = SCE_T3_S_STRING;
chQuote = '\'';
} else {
@@ -337,10 +337,10 @@ static void ColouriseTADS3String(StyleContext &sc, int &lineState) {
} else {
sc.SetState(SCE_T3_X_STRING);
}
- lineState &= ~T3_SINGLE_QUOTE;
+ lineState &= ~T3_SINGLE_TQUOTE;
} else {
sc.SetState(SCE_T3_S_STRING);
- lineState |= T3_SINGLE_QUOTE;
+ lineState |= T3_SINGLE_TQUOTE;
}
sc.Forward();
break;
@@ -528,7 +528,7 @@ static void ColouriseTADS3Doc(unsigned int startPos, int length, int initStyle,
&& sc.Match('>', '>')) {
sc.Forward(2);
sc.SetState(SCE_T3_D_STRING);
- lineState &= ~(T3_SINGLE_QUOTE|T3_INT_EXPRESSION);
+ lineState &= ~(T3_SINGLE_TQUOTE|T3_INT_EXPRESSION);
} else if (IsATADS3Operator(sc.ch)) {
if (sc.state == SCE_T3_X_DEFAULT) {
if (sc.ch == '(') {
diff --git a/src/LexTCL.cpp b/src/LexTCL.cpp
index c782141..4a651bc 100644
--- a/src/LexTCL.cpp
+++ b/src/LexTCL.cpp
@@ -43,7 +43,7 @@ static void ColouriseTCLDoc(unsigned int startPos, int length, int , WordList *k
bool foldComment = styler.GetPropertyInt("fold.comment") != 0;
bool commentLevel = false;
bool subBrace = false; // substitution begin with a brace ${.....}
- enum tLineState {LS_DEFAULT, LS_OPEN_COMMENT, LS_OPEN_DOUBLE_QUOTE, LS_COMMENT_BOX, LS_MASK_STATE = 0xf,
+ enum tLineState {LS_DEFAULT, LS_OPEN_COMMENT, LS_OPEN_DOUBLE_TQUOTE, LS_COMMENT_BOX, LS_MASK_STATE = 0xf,
LS_COMMAND_EXPECTED = 16, LS_BRACE_ONLY = 32 } lineState = LS_DEFAULT;
bool prevSlash = false;
int currentLevel = 0;
@@ -89,8 +89,8 @@ next:
sc.SetState(SCE_TCL_DEFAULT);
if (lineState == LS_OPEN_COMMENT)
sc.SetState(SCE_TCL_COMMENTLINE);
- else if (lineState == LS_OPEN_DOUBLE_QUOTE)
- sc.SetState(SCE_TCL_IN_QUOTE);
+ else if (lineState == LS_OPEN_DOUBLE_TQUOTE)
+ sc.SetState(SCE_TCL_IN_TQUOTE);
else if (lineState == LS_COMMENT_BOX && (sc.ch == '#' || (sc.ch == ' ' && sc.chNext=='#')))
sc.SetState(SCE_TCL_COMMENT_BOX);
lineState = LS_DEFAULT;
@@ -144,16 +144,16 @@ next:
w[strlen(w)-1]=0;
while(*s == ':') // ignore leading : like in ::set a 10
++s;
- bool quote = sc.state == SCE_TCL_IN_QUOTE;
+ bool quote = sc.state == SCE_TCL_IN_TQUOTE;
if (commentLevel || expected) {
if (keywords.InList(s)) {
- sc.ChangeState(quote ? SCE_TCL_WORD_IN_QUOTE : SCE_TCL_WORD);
+ sc.ChangeState(quote ? SCE_TCL_WORD_IN_TQUOTE : SCE_TCL_WORD);
} else if (keywords2.InList(s)) {
- sc.ChangeState(quote ? SCE_TCL_WORD_IN_QUOTE : SCE_TCL_WORD2);
+ sc.ChangeState(quote ? SCE_TCL_WORD_IN_TQUOTE : SCE_TCL_WORD2);
} else if (keywords3.InList(s)) {
- sc.ChangeState(quote ? SCE_TCL_WORD_IN_QUOTE : SCE_TCL_WORD3);
+ sc.ChangeState(quote ? SCE_TCL_WORD_IN_TQUOTE : SCE_TCL_WORD3);
} else if (keywords4.InList(s)) {
- sc.ChangeState(quote ? SCE_TCL_WORD_IN_QUOTE : SCE_TCL_WORD4);
+ sc.ChangeState(quote ? SCE_TCL_WORD_IN_TQUOTE : SCE_TCL_WORD4);
} else if (sc.GetRelative(-static_cast<int>(strlen(s))-1) == '{' &&
keywords5.InList(s) && sc.ch == '}') { // {keyword} exactly no spaces
sc.ChangeState(SCE_TCL_EXPAND);
@@ -169,7 +169,7 @@ next:
}
}
expected = false;
- sc.SetState(quote ? SCE_TCL_IN_QUOTE : SCE_TCL_DEFAULT);
+ sc.SetState(quote ? SCE_TCL_IN_TQUOTE : SCE_TCL_DEFAULT);
} else if (sc.state == SCE_TCL_MODIFIER || sc.state == SCE_TCL_IDENTIFIER) {
sc.SetState(SCE_TCL_DEFAULT);
}
@@ -199,8 +199,8 @@ next:
styler.SetLevel(currentLine, flag + previousLevel + SC_FOLDLEVELBASE + (currentLevel << 17) + (commentLevel << 16));
// Update the line state, so it can be seen by next line
- if (sc.state == SCE_TCL_IN_QUOTE)
- lineState = LS_OPEN_DOUBLE_QUOTE;
+ if (sc.state == SCE_TCL_IN_TQUOTE)
+ lineState = LS_OPEN_DOUBLE_TQUOTE;
else {
if (prevSlash) {
if (isComment(sc.state))
@@ -213,8 +213,8 @@ next:
(expected ? LS_COMMAND_EXPECTED : 0) | lineState);
if (lineState == LS_COMMENT_BOX)
sc.ForwardSetState(SCE_TCL_COMMENT_BOX);
- else if (lineState == LS_OPEN_DOUBLE_QUOTE)
- sc.ForwardSetState(SCE_TCL_IN_QUOTE);
+ else if (lineState == LS_OPEN_DOUBLE_TQUOTE)
+ sc.ForwardSetState(SCE_TCL_IN_TQUOTE);
else
sc.ForwardSetState(SCE_TCL_DEFAULT);
prevSlash = false;
@@ -233,7 +233,7 @@ next:
continue;
if (sc.atLineStart) {
visibleChars = false;
- if (sc.state!=SCE_TCL_IN_QUOTE && !isComment(sc.state))
+ if (sc.state!=SCE_TCL_IN_TQUOTE && !isComment(sc.state))
{
sc.SetState(SCE_TCL_DEFAULT);
expected = IsAWordStart(sc.ch)|| isspacechar(static_cast<unsigned char>(sc.ch));
@@ -245,7 +245,7 @@ next:
if (!IsANumberChar(sc.ch))
sc.SetState(SCE_TCL_DEFAULT);
break;
- case SCE_TCL_IN_QUOTE:
+ case SCE_TCL_IN_TQUOTE:
if (sc.ch == '"') {
sc.ForwardSetState(SCE_TCL_DEFAULT);
visibleChars = true; // necessary if a " is the first and only character on a line
@@ -253,7 +253,7 @@ next:
} else if (sc.ch == '[' || sc.ch == ']' || sc.ch == '$') {
sc.SetState(SCE_TCL_OPERATOR);
expected = sc.ch == '[';
- sc.ForwardSetState(SCE_TCL_IN_QUOTE);
+ sc.ForwardSetState(SCE_TCL_IN_TQUOTE);
goto next;
}
continue;
@@ -264,7 +264,7 @@ next:
if (sc.ch == '#') {
if (visibleChars) {
- if (sc.state != SCE_TCL_IN_QUOTE && expected)
+ if (sc.state != SCE_TCL_IN_TQUOTE && expected)
sc.SetState(SCE_TCL_COMMENT);
} else {
sc.SetState(SCE_TCL_COMMENTLINE);
@@ -293,7 +293,7 @@ next:
} else {
switch (sc.ch) {
case '\"':
- sc.SetState(SCE_TCL_IN_QUOTE);
+ sc.SetState(SCE_TCL_IN_TQUOTE);
break;
case '{':
sc.SetState(SCE_TCL_OPERATOR);
diff --git a/src/LineMarker.cpp b/src/LineMarker.cpp
index 6ded13c..2af78b5 100755
--- a/src/LineMarker.cpp
+++ b/src/LineMarker.cpp
@@ -68,7 +68,7 @@ void LineMarker::Draw(Surface *surface, PRectangle &rcWhole, Font &fontForCharac
pxpm->Draw(surface, rcWhole);
return;
}
- // Restrict most shapes a bit
+ // Restrict most tqshapes a bit
PRectangle rc = rcWhole;
rc.top++;
rc.bottom--;
diff --git a/src/ViewStyle.cpp b/src/ViewStyle.cpp
index b4da30a..0ae93d4 100755
--- a/src/ViewStyle.cpp
+++ b/src/ViewStyle.cpp
@@ -124,7 +124,7 @@ void ViewStyle::Init() {
fontNames.Clear();
ResetDefaultStyle();
- indicators[0].style = INDIC_SQUIGGLE;
+ indicators[0].style = INDIC_STQUIGGLE;
indicators[0].fore = ColourDesired(0, 0x7f, 0);
indicators[1].style = INDIC_TT;
indicators[1].fore = ColourDesired(0, 0, 0xff);
diff --git a/src/XPM.cpp b/src/XPM.cpp
index b8e27f4..4ce84aa 100644
--- a/src/XPM.cpp
+++ b/src/XPM.cpp
@@ -16,12 +16,12 @@
XPM::XPM(const char *textForm)
{
- qpm = *reinterpret_cast<const QPixmap *>(textForm);
+ qpm = *reinterpret_cast<const TQPixmap *>(textForm);
}
XPM::XPM(const char * const *linesForm)
{
- qpm = *reinterpret_cast<const QPixmap *>(linesForm);
+ qpm = *reinterpret_cast<const TQPixmap *>(linesForm);
}
void XPM::RefreshColourPalette(Palette &pal, bool want)
diff --git a/src/XPM.h b/src/XPM.h
index 962ffe4..27148c3 100644
--- a/src/XPM.h
+++ b/src/XPM.h
@@ -9,7 +9,7 @@
#define XPM_H
#if defined(PLAT_QT)
-#include <qpixmap.h>
+#include <tqpixmap.h>
#endif
/**
@@ -17,7 +17,7 @@
*/
class XPM {
#if defined(PLAT_QT)
- QPixmap qpm;
+ TQPixmap qpm;
public:
XPM(const char *textForm);
@@ -27,7 +27,7 @@ public:
void RefreshColourPalette(Palette &pal, bool want);
void Draw(Surface *surface,PRectangle &rc);
- const QPixmap &Pixmap() const {return qpm;}
+ const TQPixmap &Pixmap() const {return qpm;}
#else
int id; // Assigned by container
int height;
diff --git a/src/LexCPP.cpp b/src/LexCPP.cpp
index 1db0c7c..29dc6b9 100755
--- a/src/LexCPP.cpp
+++ b/src/LexCPP.cpp
@@ -21,7 +21,7 @@
#include "SciLexer.h"
#define SET_LOWER "abcdefghijklmnopqrstuvwxyz"
-#define SET_UPPER "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+#define SET_UPPER "ABCDEFGHIJKLMNOPTQRSTUVWXYZ"
#define SET_DIGITS "0123456789"
class SetOfCharacters {
@@ -319,7 +319,7 @@ static void ColouriseCppDoc(unsigned int startPos, int length, int initStyle, Wo
sc.SetState(SCE_C_IDENTIFIER);
}
} else if (sc.Match('/', '*')) {
- if (sc.Match("/**") || sc.Match("/*!")) { // Support of Qt/Doxygen doc. style
+ if (sc.Match("/**") || sc.Match("/*!")) { // Support of TQt/Doxygen doc. style
sc.SetState(SCE_C_COMMENTDOC);
} else {
sc.SetState(SCE_C_COMMENT);
@@ -327,7 +327,7 @@ static void ColouriseCppDoc(unsigned int startPos, int length, int initStyle, Wo
sc.Forward(); // Eat the * so it isn't used for the end of the comment
} else if (sc.Match('/', '/')) {
if ((sc.Match("///") && !sc.Match("////")) || sc.Match("//!"))
// Support of Qt/Doxygen doc. style
sc.SetState(SCE_C_COMMENTLINEDOC);
else
sc.SetState(SCE_C_COMMENTLINE);
@@ -327,7 +327,7 @@ static void ColouriseCppDoc(unsigned int startPos, int length, int initStyle, Wo
} else if (sc.Match('/', '/')) {
if ((sc.Match("///") && !sc.Match("////")) || sc.Match("//!"))
- // Support of Qt/Doxygen doc. style
+ // Support of TQt/Doxygen doc. style
sc.SetState(SCE_C_COMMENTLINEDOC);
else